@@ -40,10 +40,10 @@ from collections import defaultdict
 
 from hoss_agent import VERSION
 from hoss_agent.conf import constants
+from hoss_agent.conf.constants import EVENT
 from hoss_agent.contrib.async_worker import AsyncWorker
 from hoss_agent.utils import compat, json_encoder
 from hoss_agent.utils.bytes_key_to_string import bytes_key_to_string
-from hoss_agent.utils.compat import BytesIO
 from hoss_agent.utils.logging import get_logger
 from hoss_agent.utils.runtime_env import get_runtime_env
 from hoss_agent.utils.threading import ThreadManager
@@ -230,6 +230,8 @@ class Transport(ThreadManager):
     def _process_event(self, event_type, data):
         if event_type is None or data is None:
             return data
+        if event_type != EVENT:
+            return data
         # since all processor need access to the api configuration matching the host, look it up once here
         api_config = None
         if event_type == constants.EVENT and 'request' in data:
